==> bea_flutter_package-1.2.0.tar.gz: lib/bea_services/dtos/bea_models/base_models/user/get_bea_users/bea_impersonate_user.dart <==
class BeaSingleUser {
  String name;
  String surname;
  String userName;
  String fullName;
  String emailAddress;
  bool isEmailConfirmed;
  DateTime lastLoginTime;
  bool isActive;
  DateTime creationTime;
  int id;

  BeaSingleUser(
      {this.name,
        this.surname,
        this.userName,
        this.fullName,
        this.emailAddress,
        this.isEmailConfirmed,
        this.lastLoginTime,
        this.isActive,
        this.creationTime,
        this.id});

  BeaSingleUser.fromJson(Map<String, dynamic> json) {
    name = json['name'];
    surname = json['surname'];
    userName = json['userName'];
    fullName = json['fullName'];
    emailAddress = json['emailAddress'];
    isEmailConfirmed = json['isEmailConfirmed'];
    lastLoginTime = DateTime.tryParse(json['lastLoginTime'] != null ? json['lastLoginTime'] : "");
    isActive = json['isActive'];
    creationTime = DateTime.tryParse(json['creationTime'] != null ? json['creationTime'] : "");
    id = json['id'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['name'] = this.name;
    data['surname'] = this.surname;
    data['userName'] = this.userName;
    data['fullName'] = this.fullName;
    data['emailAddress'] = this.emailAddress;
    data['isEmailConfirmed'] = this.isEmailConfirmed;
    data['lastLoginTime'] = this.lastLoginTime.toIso8601String();
    data['isActive'] = this.isActive;
    data['creationTime'] = this.creationTime.toIso8601String();
    data['id'] = this.id;
    return data;
  }
}

==> bea_flutter_package-2.0.0.tar.gz: lib/bea_services/dtos/bea_models/base_models/user/get_bea_users/bea_impersonate_user.dart <==
class BeaSingleUser {
  String? name;
  String? surname;
  String? userName;
  String? fullName;
  String? emailAddress;
  bool? isEmailConfirmed;
  DateTime? lastLoginTime;
  bool? isActive;
  DateTime? creationTime;
  int? id;

  BeaSingleUser(
      {this.name,
        this.surname,
        this.userName,
        this.fullName,
        this.emailAddress,
        this.isEmailConfirmed,
        this.lastLoginTime,
        this.isActive,
        this.creationTime,
        this.id});

  BeaSingleUser.fromJson(Map<String, dynamic> json) {
    name = json['name'];
    surname = json['surname'];
    userName = json['userName'];
    fullName = json['fullName'];
    emailAddress = json['emailAddress'];
    isEmailConfirmed = json['isEmailConfirmed'];
    lastLoginTime = DateTime.tryParse(json['lastLoginTime'] != null ? json['lastLoginTime'] : "");
    isActive = json['isActive'];
    creationTime = DateTime.tryParse(json['creationTime'] != null ? json['creationTime'] : "");
    id = json['id'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['name'] = this.name;
    data['surname'] = this.surname;
    data['userName'] = this.userName;
    data['fullName'] = this.fullName;
    data['emailAddress'] = this.emailAddress;
    data['isEmailConfirmed'] = this.isEmailConfirmed;
    data['lastLoginTime'] = this.lastLoginTime!.toIso8601String();
    data['isActive'] = this.isActive;
    data['creationTime'] = this.creationTime!.toIso8601String();
    data['id'] = this.id;
    return data;
  }
}
